| jglmm_tidiers | R Documentation |
These methods tidy the coefficients and fitted values from 'jglmm' objects.
## S3 method for class 'jglmm' glance(x, ...) ## S3 method for class 'jglmm' tidy(x, ...) ## S3 method for class 'jglmm' augment(x, ...)
x |
An object of class 'jglmm', as returned by 'jglmm()'. |
... |
Optional additional arguments, currently none are used. |
'glance' returns a data frame with one row and the columns:
'tidy' returns a data frame with one row for each estimated effect. It contains the columns:
effect |
|
group |
the group within which the random effect is being estimated ( |
param |
parameter being estimated ( |
term |
term being estimated |
estimate |
estimated coefficient |
std.error |
standard error |
statistic |
z-statistic ( |
p.value |
p-value computed from z-statistic ( |
'augment' returns one row for each original observation, with these columns added:
.fitted |
predicted values |
.resid |
residuals |
## Not run:
jglmm_setup()
cbpp <- dplyr::mutate(lme4::cbpp, prop = incidence / size)
gm <- jglmm(prop ~ period + (1 | herd), data = cbpp, family = "binomial",
weights = cbpp$size)
tidy(gm)
augment(gm)
glance(gm)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.